==> dnacentersdk-2.10.0.tar.gz: dnacentersdk-2.10.0/dnacentersdk/models/validators/v2_3_7_9/jsd_ecfe864dc5012ab9c25d23e2ce9f5.py <==
# -*- coding: utf-8 -*-
"""Cisco DNA Center UpdateAnchorGroup data model.

Copyright (c) 2025 Cisco Systems.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""

from __future__ import absolute_import, division, print_function, unicode_literals

import json
from builtins import *

import fastjsonschema

from dnacentersdk.exceptions import MalformedRequest


class JSONSchemaValidatorEcfe864Dc5012Ab9C25D23E2Ce9F5(object):
    """UpdateAnchorGroup request schema definition."""
    def __init__(self):
        super(JSONSchemaValidatorEcfe864Dc5012Ab9C25D23E2Ce9F5, self).__init__()
        self._validator = fastjsonschema.compile(json.loads(
            '''{
                "$schema": "http://json-schema.org/draft-04/schema#",
                "properties": {
                "anchorGroupName": {
                "type": "string"
                },
                "mobilityAnchors": {
                "items": {
                "properties": {
                "anchorPriority": {
                "enum": [
                "PRIMARY",
                "SECONDARY",
                "TERTIARY"
                ],
                "type": "string"
                },
                "deviceName": {
                "type": "string"
                },
                "ipAddress": {
                "type": "string"
                },
                "macAddress": {
                "type": "string"
                },
                "managedAnchorWlc": {
                "type": "boolean"
                },
                "mobilityGroupName": {
                "type": "string"
                },
                "peerDeviceType": {
                "enum": [
                "IOS-XE",
                "AIREOS"
                ],
                "type": "string"
                },
                "privateIp": {
                "type": "string"
                }
                },
                "type": "object"
                },
                "type": "array"
                }
                },
                "type": "object"
                }'''.replace("\n" + ' ' * 16, '')
        ))

    def validate(self, request):
        try:
            self._validator(request)
        except fastjsonschema.exceptions.JsonSchemaException as e:
            raise MalformedRequest(
                '{} is invalid. Reason: {}'.format(request, e.message)
            )

==> dnacentersdk-2.10.1.tar.gz: dnacentersdk-2.10.1/dnacentersdk/models/validators/v3_1_3_0/jsd_ecfe864dc5012ab9c25d23e2ce9f5.py <==
# -*- coding: utf-8 -*-
"""Cisco DNA Center UpdateAnchorGroup data model.

Copyright (c) 2025 Cisco Systems.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""

from __future__ import absolute_import, division, print_function, unicode_literals

import json
from builtins import *

import fastjsonschema

from dnacentersdk.exceptions import MalformedRequest


class JSONSchemaValidatorEcfe864Dc5012Ab9C25D23E2Ce9F5(object):
    """UpdateAnchorGroup request schema definition."""

    def __init__(self):
        super(JSONSchemaValidatorEcfe864Dc5012Ab9C25D23E2Ce9F5, self).__init__()
        self._validator = fastjsonschema.compile(
            json.loads(
                """{
                "$schema": "http://json-schema.org/draft-04/schema#",
                "properties": {
                "anchorGroupName": {
                "type": "string"
                },
                "mobilityAnchors": {
                "items": {
                "properties": {
                "anchorPriority": {
                "enum": [
                "PRIMARY",
                "SECONDARY",
                "TERTIARY"
                ],
                "type": "string"
                },
                "deviceName": {
                "type": "string"
                },
                "ipAddress": {
                "type": "string"
                },
                "macAddress": {
                "type": "string"
                },
                "managedAnchorWlc": {
                "type": "boolean"
                },
                "mobilityGroupName": {
                "type": "string"
                },
                "peerDeviceType": {
                "enum": [
                "IOS-XE",
                "AIREOS"
                ],
                "type": "string"
                },
                "privateIp": {
                "type": "string"
                }
                },
                "type": "object"
                },
                "type": "array"
                }
                },
                "type": "object"
                }""".replace(
                    "\n" + " " * 16, ""
                )
            )
        )

    def validate(self, request):
        try:
            self._validator(request)
        except fastjsonschema.exceptions.JsonSchemaException as e:
            raise MalformedRequest(
                "{} is invalid. Reason: {}".format(request, e.message)
            )
